from xml.etree import ElementTree

NAMESPACE = "{http://www.mediawiki.org/xml/export-0.10/}"
PAGE_TAG = "{}page".format(NAMESPACE)
ID_TAG = "{}id".format(NAMESPACE)
TITLE_TAG = "{}title".format(NAMESPACE)
REVISION_TAG = "{}revision".format(NAMESPACE)
NS_TAG = "{}ns".format(NAMESPACE)
REDIRECT_TAG = "{}redirect".format(NAMESPACE)

TEXT_TAG = "{}text".format(NAMESPACE)
FORMAT_TAG = "{}format".format(NAMESPACE)
MODEL_TAG = "{}model".format(NAMESPACE)
TIMESTAMP_TAG = "{}timestamp".format(NAMESPACE)
COMMENT_TAG = "{}comment".format(NAMESPACE)
CONTRIBUTOR_TAG = "{}contributor".format(NAMESPACE)

USERNAME_TAG = "{}username".format(NAMESPACE)

NAMESPACES = {
    "MAIN": 0,
    "TEMPLATE": 10
}

class Wiki():
    def __init__ (self, xml_path):
        self.xml_path = xml_path

    def get_pages (self):
        tree = ElementTree.parse(self.xml_path)
        return (Page(element) for element in tree.getroot() if element.tag == PAGE_TAG)

class Page():
    def __init__ (self, element):
        self.redirect = None
        self.revisions = []
        for child in element:
            if child.tag == ID_TAG:
                self.id = child.text
            elif child.tag == NS_TAG:
                self.namespace = int(child.text)
            elif child.tag == TITLE_TAG:
                self.title = child.text
            elif child.tag == REVISION_TAG:
                self.revisions.append(Revision(child))
            elif child.tag == REDIRECT_TAG:
                self.redirect = child.attrib['title']

    def get_latest (self):
        return self.revisions[0]

class Revision():
    def __init__ (self, element):
        for child in element:
            if child.tag == ID_TAG:
                self.id = child.text
            elif child.tag == TEXT_TAG:
                self.text = child.text
            elif child.tag == CONTRIBUTOR_TAG:
                self.contributor = Contributor(child)
            elif child.tag == TIMESTAMP_TAG:
                self.timestamp = child.text
            elif child.tag == MODEL_TAG:
                self.model = child.text
            elif child.tag == COMMENT_TAG:
                self.comment = child.text

class Contributor():
    def __init__ (self, element):
        for child in element:
            if child.tag == ID_TAG:
                self.id = child.text
            elif child.tag == USERNAME_TAG:
                self.username = child.text